@@ -40,14 +40,20 @@ def main():
     list_atom_lists = [get_atom_lists(mol) for mol in args["input_files"]]
     list_filenames = [get_file_name(file) for file in args["input_files"]]
     list_energies = [get_energies(mol) for mol in args["input_files"]]
+    list_charges = [get_charge(mol) for mol in args["input_files"]]
+    list_multiplicities = [get_multiplicity(mol) for mol in args["input_files"]]
 
     # Setup orca computations
     molecules = [
-        Molecule(coordinates, list_of_atoms)
-        for coordinates, list_of_atoms in zip(list_coordinates, list_atom_lists)
+        Molecule(coordinates, list_of_atoms, charge, multiplicity)
+        for coordinates, list_of_atoms, charge, multiplicity in zip(list_coordinates, list_atom_lists, list_charges, list_multiplicities)
     ]
     basedir = Path().cwd()
-    orca_arguments = {key: value for key,value in args.items() if key in ["functional", "basisset", "solvent"]}
+    orca_arguments = {
+        key: value
+        for key, value in args.items()
+        if key in ["functional", "basisset", "solvent"]
+    }
     computations = [
         OrcaJob(
             molecule=mol,
@@ -70,7 +76,9 @@ def main():
     scf_energies = [result.get_energies()["scfenergy"] for result in orca_results]
 
     # Print everything neatly to output file
-    print_results(Path(basedir, args["output_file"]), scf_energies, list_energies, list_filenames)
+    print_results(
+        Path(basedir, args["output_file"]), scf_energies, list_energies, list_filenames
+    )
 
 
 def run_jobs(job):
@@ -83,7 +91,9 @@ def print_results(out_file, scf_energies, list_energies, list_filenames):
     with open(out_file, mode="w") as outfile:
         header = "Name\tGaussian SCF\tGaussian H\tGaussian G\tOrca SCF\tOrca H\tOrca G"
         outfile.write(header + "\n")
-        for name, orca_energy, gaussian_energies in zip(list_filenames, scf_energies, list_energies):
+        for name, orca_energy, gaussian_energies in zip(
+            list_filenames, scf_energies, list_energies
+        ):
             # Create all intermediate data to print
             orca_freeenergy = orca_energy + gaussian_energies["freeenergy_correction"]
             orca_enthalpy = orca_energy + gaussian_energies["enthalpy_correction"]
@@ -136,6 +146,18 @@ def get_coordinates(comp_file):
     return file.atomcoords[-1]
 
 
+def get_charge(comp_file):
+    """Retrieve charge from Gaussian calculation log file"""
+    file = cclib.io.ccread(comp_file.resolve().as_posix())
+    return file.charge
+
+
+def get_multiplicity(comp_file):
+    """Retrieve charge from Gaussian calculation log file"""
+    file = cclib.io.ccread(comp_file.resolve().as_posix())
+    return file.mult
+
+
 def get_atom_lists(comp_file):
     """Returns the list of atoms in the input order"""
     file = cclib.io.ccread(comp_file.resolve().as_posix())
@@ -169,13 +191,7 @@ def get_input_arguments():
 
     # List of values to extract
     values = dict.fromkeys(
-        [
-            "input_files",
-            "output_file",
-            "functional",
-            "basisset",
-            "solvent"
-        ]
+        ["input_files", "output_file", "functional", "basisset", "solvent"]
     )
 
     # Basic parser setup
